@@ -60,7 +60,7 @@
 
 #include "profiling.h"
 
-typedef enum ColorStatus { GreenStatus, RedStatus, YellowStatus };
+enum ColorStatus { GreenStatus, RedStatus, YellowStatus };
 
 ClickableLed::ClickableLed( TQWidget *parent ) : KLed(parent)
 {
