@@ -291,10 +291,13 @@ KrecipesView::KrecipesView( TQWidget *parent )
 
 KrecipesView::~KrecipesView()
 {
-	delete buttonsList;
-	delete viewPanel; //manually delete viewPanel because we need to be sure it is deleted
+    if (buttonsList)
+        delete buttonsList;
+    if (viewPanel)
+        delete viewPanel; //manually delete viewPanel because we need to be sure it is deleted
 	//before the database is because its destructor uses 'database'
-	delete database;
+    if (database)
+        delete database;
 }
 
 bool KrecipesView::questionRerunWizard( const TQString &message, const TQString &error )
